==> pandoc_2.9.2.1.orig.tar.gz: pandoc-2.9.2.1/test/command/4186.md <==
```
% pandoc -f org -t native
#+BEGIN_EXAMPLE -i
    This should retain the four leading spaces
#+END_EXAMPLE
^D
[CodeBlock ("",["example"],[]) "    This should retain the four leading spaces\n"]
```

```
% pandoc -f org -t html
- depth 1
  #+NAME: bob
  #+BEGIN_EXAMPLE -i
    Vertical alignment is four spaces beyond the appearance of the word "depth".
  #+END_EXAMPLE
       - depth 2
         #+begin_example
                          Vertically aligned with the second appearance of the word "depth".
         #+end_example
              #+begin_example -i
    Vertical alignment is four spaces beyond the second
    appearance of the word "depth".
    The "begin" portion is a component of
    this deeper list element, so that guarantees
    that the entire block must be a component of the
    inner list element.
    #+end_example
         Still inside the inner list element
   #+NAME: carrie
                         #+BEGIN_EXAMPLE
                           This belongs to the outer list element, and is aligned accordingly, since the NAME attribute is not indented deeply enough. It is not enough for the BEGIN alone to be aligned deeply if the block is meant to have a NAME.
                           #+END_EXAMPLE
                 Still in the shallower list element since the preceding example
                 block forced the deeper list element to terminate.
Outside all lists.
^D
<ul>
<li><p>depth 1</p>
<pre id="bob" class="example"><code>    Vertical alignment is four spaces beyond the appearance of the word &quot;depth&quot;.
</code></pre>
<ul>
<li><p>depth 2</p>
<pre class="example"><code>Vertically aligned with the second appearance of the word &quot;depth&quot;.
</code></pre>
<pre class="example"><code>    Vertical alignment is four spaces beyond the second
    appearance of the word &quot;depth&quot;.
    The &quot;begin&quot; portion is a component of
    this deeper list element, so that guarantees
    that the entire block must be a component of the
    inner list element.
</code></pre>
<p>Still inside the inner list element</p></li>
</ul>
<pre id="carrie" class="example"><code>This belongs to the outer list element, and is aligned accordingly, since the NAME attribute is not indented deeply enough. It is not enough for the BEGIN alone to be aligned deeply if the block is meant to have a NAME.
</code></pre>
<p>Still in the shallower list element since the preceding example block forced the deeper list element to terminate.</p></li>
</ul>
<p>Outside all lists.</p>
```

==> pandoc-3.9.tar.gz: pandoc-3.9/test/command/4186.md <==
```
% pandoc -f org -t native
#+begin_example -i
    This should retain the four leading spaces
#+end_example
^D
[ CodeBlock
    ( "" , [] , [] )
    "    This should retain the four leading spaces\n"
]
```

```
% pandoc -f org -t html
- depth 1
  #+name: bob
  #+begin_example -i
    Vertical alignment is four spaces beyond the appearance of the word "depth".
  #+end_example
       - depth 2
         #+begin_example
                          Vertically aligned with the second appearance of the word "depth".
         #+end_example
              #+begin_example -i
    Vertical alignment is four spaces beyond the second
    appearance of the word "depth".
    The "begin" portion is a component of
    this deeper list element, so that guarantees
    that the entire block must be a component of the
    inner list element.
    #+end_example
         Still inside the inner list element
   #+name: carrie
                         #+begin_example
                           This belongs to the outer list element, and is aligned accordingly, since the NAME attribute is not indented deeply enough. It is not enough for the BEGIN alone to be aligned deeply if the block is meant to have a NAME.
                           #+end_example
                 Still in the shallower list element since the preceding example
                 block forced the deeper list element to terminate.
Outside all lists.
^D
<ul>
<li><p>depth 1</p>
<pre id="bob"><code>    Vertical alignment is four spaces beyond the appearance of the word &quot;depth&quot;.
</code></pre>
<ul>
<li><p>depth 2</p>
<pre><code>Vertically aligned with the second appearance of the word &quot;depth&quot;.
</code></pre>
<pre><code>    Vertical alignment is four spaces beyond the second
    appearance of the word &quot;depth&quot;.
    The &quot;begin&quot; portion is a component of
    this deeper list element, so that guarantees
    that the entire block must be a component of the
    inner list element.
</code></pre>
<p>Still inside the inner list element</p></li>
</ul>
<pre id="carrie"><code>This belongs to the outer list element, and is aligned accordingly, since the NAME attribute is not indented deeply enough. It is not enough for the BEGIN alone to be aligned deeply if the block is meant to have a NAME.
</code></pre>
<p>Still in the shallower list element since the preceding example block
forced the deeper list element to terminate.</p></li>
</ul>
<p>Outside all lists.</p>
```
